@@ -4,7 +4,7 @@ use Exporter 'import';
 use Digest::MD5 qw(md5_hex);
 
 use 5.010;
-our $VERSION = '1.610'; # ==> ALSO update the version in the pod text below!
+our $VERSION = '1.611'; # ==> ALSO update the version in the pod text below!
 
 # loaded modules
 our %TAG_HANDLERS;
@@ -345,7 +345,7 @@ DTL::Fast - Perl implementation of Django templating language.
 
 =head1 VERSION
 
-Version 1.610
+Version 1.611
 
 =head1 SYNOPSIS
 
@@ -543,6 +543,12 @@ This module supports almost all built-in tags documented on L<official Django si
 
 New tag, that works like C<firstof> tag, but checks if value is defined (not true)
 
+=head3 sprintf
+
+    {% sprintf pattern var1 var2 ... varn %}
+    
+Works exactly like a perl's sprintf function with pattern and substitutions. This tag was recently implemented and should be considered as experimental.
+
 =head3 url
 
 C<url> tag works a different way. Because there is no framework around, we can't obtain model's path the same way. But you may pass C<url_source> parameter into template constructor or C<get_template>/C<select_template> function. This parameter MUST be a reference to a function, that will return to templating engine url template by some 'model path' (first parameter of C<url> tag). Second parameter passed to the C<url_source> handler will be a reference to array of argument values (in case of positional arguments) or reference to a hash of arguments (in case of named ones). Url source handler may just return a regexp template by model path and templating engine will try to restore it with specified arguments. Or, you may restore it yourself, alter replacement arguments or do whatever you want. 
@@ -561,7 +567,7 @@ This module supports all built-in filters documented on L<official Django site|h
 
 =head3 numberformat
 
-    {% var1|numberformat %}
+    {{ var1|numberformat }}
     
 Formats 12345678.9012 as
     
@@ -585,6 +591,12 @@ Reverses data depending on type:
 
 =back
 
+=head3 split
+
+    {{ var1|split:"\s+"|slice:":2"|join:"," }}
+    
+Splitting variable with specified pattern, using Perl's split function. Current implementation uses //s regexp. Filter returns array. This filter was recently implemented and should be considered as experimental.
+
 =head3 strftime
 
 Formatting timestamp using L<C<Date::Format>> module. This is C-style date formatting, not PHP one.
