@@ -6,6 +6,8 @@ use DTL::Fast::Context;
 use DTL::Fast::Tags;
 use DTL::Fast::Filters;    
 
+our $CURRENT_TEMPLATE;  # global variable for linking  modules
+
 #@Override
 sub new
 {
@@ -37,7 +39,7 @@ sub new
     push @{$kwargs{'inherited'}}, $kwargs{'file_path'};
     
     my $self = $proto->SUPER::new(%kwargs);
-
+    
     if( $self->{'extends'} )
     {
         my $parent_template = DTL::Fast::read_template(
@@ -52,7 +54,7 @@ sub new
         else
         {
             die  sprintf( "Couldn't found a parent template: %s in one of the following directories: %s"
-                , $self->{'extends' }
+                , $self->{'extends' } // 'undef'
                 , join( ', ', @{$kwargs{'dirs'}})
             );
         }
@@ -83,6 +85,20 @@ sub merge_template
     return $self;
 }
 
+#@Override
+sub parse_chunks
+{
+    my( $self ) = @_;
+    
+    my $current_template_backup = $CURRENT_TEMPLATE;
+    $CURRENT_TEMPLATE = $self;
+    
+    $self->SUPER::parse_chunks();
+    
+    $CURRENT_TEMPLATE = $current_template_backup;
+    return $self;
+}
+
 #@Override
 sub get_container_block{ return shift; }
 
